.. _developers:

Development
===========

.. note::

   If you are new to sktime, it may be helpful to take a look at the
   :ref:`get_involved` page first.

.. toctree::
   :maxdepth: 1
   :hidden:

   developer_guide
   reviewer_guide
   enhancement_proposals
   roadmap
   code_of_conduct
   governance

.. panels::
    :card: + intro-card text-center

    ---

    Developer Guide
    ^^^^^^^^^^^^^^^

    Learn our development conventions.

    +++

    .. link-button:: developer_guide
            :type: ref
            :text: Developer Guide
            :classes: btn-block btn-secondary stretched-link

    ---

    Reviewer Guide
    ^^^^^^^^^^^^^^

    How we review contributions.

    +++

    .. link-button:: reviewer_guide
            :type: ref
            :text: Reviewer Guide
            :classes: btn-block btn-secondary stretched-link

    ---

    Enhancement Proposals
    ^^^^^^^^^^^^^^^^^^^^^

    Thought of a project enhancement? See when and how to submit a proposal.

    +++

    .. link-button:: enhancement_proposals
            :type: ref
            :text: Enhancement Proposals
            :classes: btn-block btn-secondary stretched-link

    ---

    Roadmap
    ^^^^^^^

    What's on the development horizon?

    +++

    .. link-button:: roadmap
            :type: ref
            :text: Roadmap
            :classes: btn-block btn-secondary stretched-link

    ---

    Code of Conduct
    ^^^^^^^^^^^^^^^


    +++

    .. link-button:: code_of_conduct
            :type: ref
            :text: Code of Conduct
            :classes: btn-block btn-secondary stretched-link

    ---

    Governance
    ^^^^^^^^^^

    How ``sktime`` is run.

    +++

    .. link-button:: governance
            :type: ref
            :text: Governance
            :classes: btn-block btn-secondary stretched-link
